embassy-nrf

Crates

git

Versions

nrf9120-s

Flavors

Itctrl

Struct Itctrl 

#[repr(transparent)]
pub struct Itctrl(pub u32);
The ITCTRL register enables the component to switch from a functional mode, which is the default behavior, to integration mode where the inputs and outputs of the component can be directly controlled for the purposes of integration testing and topology detection.

Tuple Fields

0: u32

Implementations

Source

impl Itctrl

pub const fn ime(&self) -> bool

Integration Mode Enable.

pub const fn set_ime(&mut self, val: bool)

Integration Mode Enable.